@@ -11,6 +11,9 @@ import os
 import re
 import sys
 
+from os import listdir
+from os.path import isdir, exists, isfile, abspath, join
+
 import pkg_resources
 import yaml
 
@@ -554,7 +557,7 @@ class AnalyseLVars(Rule):  # pylint: disable=too-many-instance-attributes
         self._function_p = re.compile(r"\bfunction\b")
         self._end_p = re.compile(r"\bend\b")
         self._local_p = re.compile(r"\blocal\b")
-        self._var_p = re.compile(r"\w+")
+        self._var_p = re.compile(r"\w+\s*\w*")
         self._ass_var_p = re.compile(r"([a-zA-Z0-9_\.]+)\s*:=")
         self._use_var_p = re.compile(r"(\b\w+\b)(?!\s*:=)\W*")
         self._ws1_p = re.compile(r"[ \t\r\f\v]+")
@@ -619,6 +622,17 @@ class AnalyseLVars(Rule):  # pylint: disable=too-many-instance-attributes
         args = self._func_args[self._depth]
 
         for var in new_args:
+            var = [x.strip() for x in var.split(" ") if len(x) != 0]
+            if len(var) == 1:
+                var = var[0].strip()
+            elif len(var) != 2 or var[0] not in ("readonly", "readwrite"):
+                _error(
+                    fname,
+                    lines.count("\n", 0, pos),
+                    'Invalid syntax: "%s"' % lines[start:end],
+                )
+            else:
+                var = var[1].strip()
             if var in args:
                 _error(
                     fname,
@@ -682,6 +696,7 @@ class AnalyseLVars(Rule):  # pylint: disable=too-many-instance-attributes
 
         new_lvars = self._var_p.findall(lines, pos, end)
         for var in new_lvars:
+            var = var.strip()
             if var in lvars:
                 _error(
                     fname,
@@ -1059,7 +1074,7 @@ def _parse_args(kwargs):
 
     files = []
     for fname in args.files:
-        if not (os.path.exists(fname) and os.path.isfile(fname)):
+        if not (exists(fname) and isfile(fname)):
             _info_action("SKIPPING " + fname + ": cannot open for reading")
         elif (
             not fname.split(".")[-1] in _VALID_EXTENSIONS
@@ -1103,24 +1118,17 @@ def __config_yml_path(dir_path):
     root directory has been searched (script not found, returns None) - base
     cases A, B, C.
     """
-    assert os.path.isdir(dir_path)
-    entries = os.listdir(dir_path)  # initialise list of entries in the...
-    # ...directory we are currently searching
-    for entry in entries:
-        # if entry a directory, True, else False
-        entry_isdir = os.path.isdir(
-            os.path.abspath(os.path.join(dir_path, entry))
-        )
-        if entry_isdir and entry == ".git":  # base case A
-            return None
-        if not entry_isdir and entry == ".gaplint.yml":  # base case B
-            yml_path = os.path.abspath(os.path.join(dir_path, ".gaplint.yml"))
-            return yml_path
-    # if A and B not satisfied, recursive call made on parent directory
-    pardir_path = os.path.abspath(os.path.join(dir_path, os.pardir))
-    # when os.pardir is called on the root directory path, it just returns the
-    # path to the root directory again, hence
-    if pardir_path == dir_path:  # base case C
+    assert isdir(dir_path)
+    entries = listdir(dir_path)
+
+    if ".gaplint.yml" in entries:
+        yml_path = abspath(join(dir_path, ".gaplint.yml"))
+        return yml_path
+    if ".git" in entries and isdir(abspath(join(dir_path, ".git"))):
+        return None
+
+    pardir_path = abspath(join(dir_path, os.pardir))
+    if pardir_path == dir_path:
         return None
     return __config_yml_path(pardir_path)  # recursive call
 
@@ -1173,7 +1181,10 @@ def __verify_glob_suppressions():
         if name_or_code in ("all", ""):
             continue
         ok = False
-        for rule in _LINE_RULES:
+        for rule in _LINE_RULES + _FILE_RULES:
+            if isinstance(rule, GlobalRules):
+                ok = True
+                continue
             if name_or_code in (rule.name, rule.code):
                 if rule.code[0] == "M":
                     _info_action(
@@ -1396,7 +1407,10 @@ def __is_valid_rule_name_or_code(name_or_code, fname, linenum):
     # TODO assertions
     if name_or_code == "all":
         return True
-    for rule in _LINE_RULES:
+    for rule in _LINE_RULES + _FILE_RULES:
+        if isinstance(rule, GlobalRules):
+            continue
+
         if name_or_code in (rule.name, rule.code):
             if rule.code[0] == "M":
                 _info_action("IGNORING cannot disable rule: %s" % name_or_code)
@@ -1487,7 +1501,10 @@ def _is_rule_suppressed(fname, linenum, rule):
     """
     assert isinstance(fname, str)
     assert isinstance(linenum, int)
-    assert isinstance(rule, Rule)
+    assert isinstance(rule, (Rule, GlobalRules))
+
+    if isinstance(rule, GlobalRules):
+        return False
 
     if rule.code[0] == "M":
         return False
@@ -1572,9 +1589,9 @@ def main(**kwargs):
 
         nr_warnings = 0
         for rule in _FILE_RULES:
-            # TODO can't suppress these so far
-            nr_warnings, lines = rule(fname, lines, nr_warnings)
-            too_many_warnings(nr_warnings + total_nr_warnings)
+            if not _is_rule_suppressed(fname, 0, rule):
+                nr_warnings, lines = rule(fname, lines, nr_warnings)
+                too_many_warnings(nr_warnings + total_nr_warnings)
         lines = lines.split("\n")
         for linenum in range(len(lines)):
             for rule in _LINE_RULES:
